#define PERL_NO_GET_CONTEXT
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"
#define NEED_newRV_noinc
#define NEED_sv_2pv_flags
#include "ppport.h"

#include <string.h>


enum {
	SL_REQ_METHOD,
	SL_REQ_PATH,
	SL_REQ_PROTOCOL,
	SL_REQ_HEADERS,
	SL_REQ_NAME,
	SL_REQ_VALUE
};


static int URIdecode (const char *src, char *dest, int len) {
	int j = 0;
	char hex[3] = {0};

	for (int i = 0; i < len; i++) {
		if (src[i] == '%' && i < len-2) {
			i++;
			strncpy(hex, &src[i++], 2);
			long c = strtol(hex, NULL, 16);
			if (c <= 0) break;
			dest[j] = (char)c;
		} else if (src[i] == '+') dest[j] = ' ';
		else dest[j] = src[i];
		j++;
	}

	dest[j] = '\0';

	return j; // length of decoded copy
}


/* void addQSpair (HV *query, char *raw_name, char *raw_value, int decode)
 'query' is a hash of arrays keyed by name (the array is created if the key does not
         exist). A value is pushed onto the appropriate array.
 'raw_name' is the name for the pair.
 'raw_value' is the value for the pair.
 'decode' is a boolean indicating whether raw_name and raw_value need to be URI_decoded. */
static void addQSpair (HV *query, const char *raw_name, const char *raw_value, int decode) {
	dTHX;
	if (*raw_name == '\0') return;

	int nlen = strlen(raw_name),
		vlen = 0;

	if (raw_value) vlen = strlen(raw_value);
	char name[nlen + 1];
	char value[vlen + 1];

	if (decode) {
		nlen = URIdecode(raw_name, name, nlen);
		if (raw_value) vlen = URIdecode(raw_value, value, vlen);
	} else {
		nlen = strlen(raw_name);
		strcpy(name, raw_name);
		if (raw_value) strcpy(value, raw_value);
	}

	SV **field = hv_fetch(query, name, nlen, 0);

	// All values go into an array
	if (field) {
		AV *ray = (AV*)SvRV(*field);
		if (vlen) av_push(ray, newSVpv(value, vlen));
	} else {
		AV *ray = newAV();
		if (vlen) av_push(ray, newSVpv(value, vlen));
		hv_store(query, name, nlen, newRV_noinc((SV*)ray), 0);
	}

}


/* badRequest (char *msg)
 'msg' is a pointer to a text error message.
 Used to bail from parse(). */
void badRequest (HV *obj, char *errstr) {
	dTHX;
	hv_store(obj, "bad", 3, newSVpv(errstr, strlen(errstr)), 0);
}


static void lowercase (char *txt) {
	int i, len = strlen(txt);
	for (i = 0; i < len; i++) txt[i] = tolower(txt[i]);
}


/* HV *doHeaders (char **data)
 'data' is a pointer to a pointer to the raw HTTP request headers.
        '*data' will be left pointing to the first character after the CRLRCRLF
        sequence which ends the headers.
Called from getHeaders() or parse(), below.
Returns a hash of key (lower case header name) value (header text) pairs. */
static HV *doHeaders (char **data) {
	dTHX;
	HV *hdrs = newHV();
	char *val = NULL,
		*p = *data;
	int state = SL_REQ_NAME;
	SV **cur; // current key

	while (1) {

	// Extract field name.
		if (state == SL_REQ_NAME) {
			char *name = p;
			int done = 0;
			while (!done) {
				char c = *p;
				switch (c) {
					case ':':
					// Field name complete.
						*p = '\0';
						done = 1;
						break;
					case '\r':
					// Malformed.
						SvREFCNT_dec(hdrs);
						return NULL;
					default: p++;
				}
			}

			lowercase(name);

		// Get matching key from hdrs hash, creating if necessary.
			cur = hv_fetch(hdrs, name, name - p, 1);
			if (!SvOK(*cur)) {
				SvREFCNT_dec(*cur);
				*cur = newSVpv("", 0);
			}

			state = SL_REQ_VALUE;
			p++;
			continue;
		}

	// Extract field value (state == SL_REQ_VALUE is implicit).
		if (!val) {
		// Set 'val' to first character in value by advancing past non-CRLF LWS
		// (LWS/linear-white-space in RFC 822 = space tab CRLF).
			val = p;
			while (*val == ' ' || *val == '\t') val++;
		}

		// Advance p to end of value.
		while (!(p[0] == '\r' && p[1] == '\n')) p++;

		// Check next line.
		p += 2;
		if (*p == ' ' || *p == '\t') {
			// Value spans multiple lines; note the intervening  CRLF is left in.
			p++;
			continue;
		}
		// Field is complete, null terminate value.
		*(p-2) = '\0';

		// Separate multiple values with comma.
		if (SvCUR(*cur)) sv_catpv(*cur, ",");
		sv_catpv(*cur, val);

		if (p[0] == '\r' && p[1] == '\n') {
		// CRLFCRLF -- this is guaranteed, see Client->takeRequest.
			p += 2;
			break;
		}

		// Start next header.
		state = SL_REQ_NAME;
		val = NULL;
	}

	*data = p; // Beginning of body, if any.
	return hdrs;
}


MODULE = Sloop::Client::Request		PACKAGE = Sloop::Client::Request

PROTOTYPES: ENABLE


HV *getHeaders (dref)
SV *dref
CODE:
// Wrapper for doHeaders.
	// Validate reference.
	if (!SvROK(dref)) XSRETURN_EMPTY;
	SV *data = SvRV(dref);
	if (
		SvTYPE(data) >= SVt_PVAV
		|| !SvPOK(data)
	) XSRETURN_EMPTY;

	// Keep two pointers to calculate length of data post processing.
	char *start = SvPV_nolen(data),
		*p = start;
	HV *hdrs = doHeaders(&p);
	if (!hdrs) XSRETURN_EMPTY;

	// Change the reference to refer to the remaining data.
	SvRV_set(dref, newSVpv(p, SvCUR(data) - (p - start)));
	SvREFCNT_dec(data);
	sv_2mortal((SV*)hdrs);
	RETVAL = hdrs;
OUTPUT:
	RETVAL


SV *parse (raw, len)
char *raw
int len
CODE:
/* SV *parse (char *raw)
 'raw' is a pointer to the beginning of an HTTP request, qv. RFC 2616 sec. 5
Called from the constructor, returns a hash ref. The constructor is called from
Client->takeRequest, which ensures there is a final CRLFCRLF and that the
total request is  <= Client->{max_recv}. */
	int state = SL_REQ_METHOD;
	char *p = raw,
		*start = p,
		*stop = raw + len;
	HV *rv = newHV();

	while (p < stop) {
	/* We do not have to be paranoid about length here on the presumption that a non-block
	server is only going to feed fairly short chunks.  The HTTP 1.x Request Line is extracted
	in SL_REQ_METHOD->SL_REQ_PATH->SL_REQ_PROTOCOL states. */

		if (state == SL_REQ_METHOD) {
			// The method is a word in CAPS.
			while (*p >= 'A' && *p <= 'Z') p++;
			if (p == start) {
				badRequest(rv, "No recognizable method.");
				ST(0) = newRV_noinc((SV*)rv);
				XSRETURN(1);
			}
			*p = '\0';
			lowercase(start);
			hv_store(rv, "method", 6, newSVpv(start, 0), 0);

			p++;
			state = SL_REQ_PATH;
			continue;
		}

		if (state == SL_REQ_PATH) {
		// Now turn path into an array...
			AV *path = newAV();

			// Path should be on the same line as the method, separated by space character(s)
			while (*p == ' ' || *p == '\t') p++;

			// Path must be "*" or absolute.
			if (*p == '*') {
				av_push(path, newSVpv(p, 1));
				p++;
				if (*p > 32) {
					badRequest(rv, "Invalid path");
					ST(0) = newRV_noinc((SV*)rv);
					XSRETURN(1);
				}
				goto path_complete;
			} else if (*p != '/') {
				badRequest(rv, "Invalid path");
				ST(0) = newRV_noinc((SV*)rv);
				XSRETURN(1);
			}

			p++;

			while (1) {
			// Each iteration extracts an element of the path array.
				while (*p == '/') p++;
				int flag = 0;
				start = p; // First non-slash

				// Iterate to next slash, whitespace, or '?'
				while (1) {
					if (*p == '/') break;
					if (*p <= 32) {
					// Path is finished.
						// If the previous character was slash, it may already have
						// been transformed to a null.
						if (*(p-1) == '\0' || *(p-1) == '/')
							hv_store(rv, "slash_end", 9, newSViv(1), 0);
						else hv_store(rv, "slash_end", 9, newSViv(0), 0);
						flag = 1;
						break;
					}
					if (*p == '?') {
					// Path is terminated with a query string.
						if (*(p-1) == '\0' || *(p-1) == '/')
							hv_store(rv, "slash_end", 9, newSViv(1), 0);
						else hv_store(rv, "slash_end", 9, newSViv(0), 0);
						flag = 2;
						break;
					}
					p++;
				}
				*p = '\0';

				// Add this segment to the path array.
				if (p > start && !(start[0] == '.' && start[1] == '.')) {
					// but ignore '..' for security
					av_push(path, newSVpv(start, p-start));
				}

				if (flag == 2) {
				// query string
					start = p+1;
					if (*start <= 32) break;
					p++;
					while (*p > 32) p++;
					*p = '\0';
					hv_store(rv, "qstr", 4, newRV_noinc(newSVpv(start, p-start)), 0);
				}

				p++;
				if (flag) break;  // path is complete
			}

		path_complete:
			hv_store(rv, "path", 4, newRV_noinc((SV*)path), 0);
			state = SL_REQ_PROTOCOL;
			continue;
		}

		if (state == SL_REQ_PROTOCOL) {
		// Protocol should be on the same line as the path.
			while (*p == ' ' || *p == '\t') p++;
			if (*p < 32) // no protocol
				hv_store(rv, "protocol", 8, newSVpv("???", 3), 0);
			else {
				start = p;
				while (*p > 32) p++;
				*p = '\0';
				hv_store(rv, "protocol", 8, newSVpv(start, p-start), 0);
			}

			// get to the beginning of the next line
			while (*p != '\n') p++;
			p++;
			state = SL_REQ_HEADERS;
			continue;	// loop condition checks bounds
		}

		if (state == SL_REQ_HEADERS) {
			// are there headers?
			if (*p == '\r') { // no
				hv_store(rv, "headers", 7, newSV(0), 0);
				p += 2;
			} else { // yes
				HV *hdrs = doHeaders(&p);
				if (!hdrs) {
					badRequest(rv, "Malformed or incomplete headers.");
					ST(0) = newRV_noinc((SV*)rv);
					XSRETURN(1);
				}
				hv_store(rv, "headers", 7, newRV_noinc((SV*)hdrs), 0);
			}

			hv_store(rv, "body", 4, newSVpv(p, (int)(stop-p)), 0);
			break;
		}
	}

	RETVAL = newRV_noinc((SV*)rv);
OUTPUT:
	RETVAL


SV *qargsFromString (qs, decode)
char *qs
int decode
CODE:
/*	'str' string to parse.
 	'decode' boolean indicating whether the string needs to be URI decoded. 
Returns a hash reference. */
	int state = SL_REQ_NAME;
	HV *rv = newHV();
	char *name = qs,
		*value = NULL;

	while (*qs) {
		switch (*qs) {
			case '=':
				if (state == SL_REQ_VALUE) {
				// malformed
					ST(0) = newRV_noinc((SV*)rv);
					XSRETURN(1);
				} else {
					*qs = '\0';
					value = qs+1;
					state = SL_REQ_VALUE;
				}
				break;
			case '&':
				if (state == SL_REQ_NAME) value = NULL; // name without value
				*qs = '\0';
				if (name < qs) addQSpair(rv, name, value, decode);
				name = qs+1;
				state = SL_REQ_NAME;
			default: break;
		}
		qs++;
	}
	if (state == SL_REQ_NAME) value = NULL;
	if (name < qs) addQSpair(rv, name, value, decode);

	RETVAL = newRV_noinc((SV*)rv);
OUTPUT:
	RETVAL
