package Sloop::Client::Regular;
our $VERSION = '0.1.0';
use strict;
use warnings;

use parent qw(Sloop::Socket::Standard Sloop::Client);

=encoding utf8

=head1 NAME

Sloop::Client::Regular

=head1 DESCRIPTION

Default class used by Sloop::Server to create objects representing
accepted client connections.  Conjoins the functionality of its parents,
Sloop::Client and Sloop::Socket::Standard.

=head1 SYNOPSIS

Invocation is the same as for the Sloop::Client superclass (although sloop
client objects should not be created except by the server).

Sloop::Client::Regular sets the 'id' field inherited from Sloop::Base
to 'fdN', where N is the file descriptor number.

The API is entirely inherited from Sloop::Client.

=cut

sub new {
	my $class = shift;
	my %args = ( @_ );

	my $self = $class->SUPER::new (
		id => "fd$args{fd}",
		%args
	);

	bless $self, $class;
}


1;
