use strict;
use warnings;

use Test::More tests => 7;
BEGIN { use_ok('Sloop::Client::Request') };

# Value spanning multiple lines.
my $val = "This\r\n that\r\n and that.";
my $req = Sloop::Client::Request->new (\"GET / HTTP/1.1\r\nMulti-line: $val\r\n\r\n");
isa_ok($req, 'Sloop::Client::Request', 'ISA 1');
is (
	$req->{headers}->{'multi-line'},
	$val,
	'Multi-line'
);

# Multiple values entered separately.
my $txt = <<END;
GET / HTTP/1.1\r
Foo: This\r
Bar: None\r
Foo: ...and that\r
\r
END
$req = Sloop::Client::Request->new(\$txt);
isa_ok($req, 'Sloop::Client::Request', 'ISA 2');
is_deeply (
	$req->{headers},
	{
		bar => "None",
		foo => "This,...and that"
	},
	'Multiple value'
);

# No headers should return an empty hash.
$req = Sloop::Client::Request->new(\"GET / HTTP/1.1\r\n\r\n");
isa_ok($req, 'Sloop::Client::Request', 'ISA 3');
is_deeply($req->{headers}, {}, 'No headers');
