use strict;
use warnings;

use Test::More tests => 4;
BEGIN { use_ok('Sloop::Client') };

use Sloop::Logger;
use Sloop::Client::Request;
use Sloop::Client::Regular;
use Sloop::Constants;

my $garbage = "";
open my $discard, '>', \$garbage;

my $client = Sloop::Client::Regular->new (
	id => 'Test',
	fd => -1,
	epfd => -1,
	logger => Sloop::Logger->new (
		logs => [ $discard, \*STDOUT, \*STDOUT ]
	),
	request => Sloop::Client::Request->new (
		\"GET / HTTP/1.1\r\n\r\n"
	)
);
isa_ok($client, 'Sloop::Client');

is (
	$client->reply (
		\"Hello world.\n",
		status => 404,
		maxage => 3600,
		cookies => [ "foo=bar;" ],
		extra => {
			Accept => 'defeat'
		}
	),
	Sloop::Constants::READY_CANCEL,
	'State'
);

my $text = <<END;
HTTP/1.1 404 Not Found\r
Server: Perl Sloop\r
Cache-Control: max-age=3600\r
Content-Length: 13\r
Content-Type: text/html; charset=UTF-8\r
Connection: close\r
Accept: defeat\r
Set-Cookie: foo=bar;\r
\r
Hello world.
END

is_deeply (
	$client->{data_pending},
	\$text,
	'Reply'
);
