use strict;
use warnings;

use Test::More tests => 5;
BEGIN { use_ok('Sloop::Client::TokenAuth') };

use Sloop::Client::Request;

my $auth = Sloop::Client::TokenAuth->new (
	cookieName => '(tatest?)',
	tokenSize => 4,
	checkIP => 1,
	duration => 1,
	attributes => {
		path => '/foo',
		secure => 1
	}
);

my $data = {
	a => 1,
	ok => 'bar'
};
my $token = $auth->add('1.2.3.4', $data);
my $cookie = $auth->cookie($token, 'userBob');

# Remove date in 'Expires' for brevity.
(my $copy = $cookie) =~ s/Expires=[A-Za-z]{3}, \d\d-[A-Za-z]{3}-\d\d\d\d \d\d:\d\d:\d\d [A-Z]{3}/Expires=/;

ok (
	$copy eq
	"tatestuserBob=$token; Expires=; max-age=60; Path=/foo; Secure",
	'Cookie check.'
);

my $http = <<END;
GET / HTTP/1.1\r
Cookie: $cookie\r
\r
END

my $client = {
	request => Sloop::Client::Request->new(\$http),
	ip => '1.2.3.4'
};

my $check = $auth->validate($client, 'userBob');
ok($check eq $token, 'Validate check.');

$check = $auth->fetch($token);
is_deeply($check, $data, 'Data check.');

$auth->{duration} = 1;
sleep 2;
$auth->purge;
is_deeply($auth->{validTokens}, {}, 'Purge check.');
