#define PERL_NO_GET_CONTEXT
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"
#define NEED_sv_2pv_flags
#include "ppport.h"

#include <string.h>

static void lowercase (char *txt) {
	int i, len = strlen(txt);
	for (i = 0; i < len; i++) txt[i] = tolower(txt[i]);
}

static void purgeWS (char *str) {
// In-place strips whitespace outside quotes and strips quotes.
	int len = strlen(str), i, j = 0, inquotes = 0;

	for (i = 0; i < len; i++) {
		if (!inquotes && str[i] <= 32) continue;
		if (str[i] == '"') {
			if (inquotes) {
				if (str[i-1] == '\\') str[j++] = str[i];
				else inquotes = 0;
			}
			else inquotes = 1;
		} else str[j++] = str[i];
	}
	str[j] = '\0';
}


MODULE = Sloop::Lib		PACKAGE = Sloop::Lib

PROTOTYPES: ENABLE


int dataLength (ref)
SV *ref
CODE:
// Returns the length of a scalar from a REFERENCE.
	if (!SvROK(ref)) {
		ST(0) = newSViv(-1);
		XSRETURN(1);
	}
	SV *data = SvRV(ref);
	if (SvTYPE(data) >= SVt_PVAV) RETVAL = -2;
	if (!SvPOK(data)) {
	// Numbers, e.g., need to be coerced to strings to get the length.
		STRLEN len = -3;
		SvPV(data, len);
		RETVAL = len;
	} else RETVAL = SvCUR(data);
OUTPUT:
	RETVAL


SV *errorString (err)
int err
CODE:
	// See comment in Server.xs Epoll() regarding strerror vs. strerror_r.
	char *msg = strerror(err);
	RETVAL = newSVpv(msg, strlen(msg));
OUTPUT:
	RETVAL


SV *fastSlurp (path)
char *path
CODE:
// Returns content of file at 'path', or undef.
// You can check errno w/ $!.
	struct stat info;
	if (stat(path, &info)) XSRETURN_UNDEF;

	char *buf = malloc(info.st_size);
	int fd = open(path, O_RDONLY);
	if (fd == -1) XSRETURN_UNDEF;

	ssize_t bytes = read(fd, buf, info.st_size);
	close(fd);

	RETVAL = newSVpv(buf, bytes);
	free(buf);
OUTPUT:
	RETVAL


HV *fieldPairs (data, lc)
char *data
int lc
CODE:
/* Splits semi-colon delimited elements in a singular HTTP header value
and returns a hash (reference) of field names with values. 'lc' indicates to
lowercase the keys. */
	HV *pairs = newHV();
	purgeWS(data);
	char *p,
		*name = strtok_r(data, ";", &p),
		*value,
		empty[]="";

	while (name) {
		if ((value = strchr(name, '='))) {
			*value = '\0';
			value++;
		} else value = empty;
		if (lc) lowercase(name);
		hv_store(pairs, name, strlen(name), newSVpv(value, 0), 0);
		name = strtok_r(NULL, ";", &p);
	}

	sv_2mortal((SV*)pairs);
	RETVAL = pairs;
OUTPUT:
	RETVAL


SV *lcSuffix (fname)
char *fname
CODE:
	char *dot = strrchr(fname, '.');
	if (!dot) XSRETURN_UNDEF;;
	int sz = strlen(++dot);
	char suf[sz];
	for (int i = 0; i < sz; i++) suf[i] = tolower(dot[i]);
	RETVAL = newSVpv(suf, sz);
OUTPUT:
		RETVAL


void lowerCase (txt)
char *txt
CODE:
// Lowercases 'txt'; unlike lc() this does not require re-assignment.
	lowercase(txt);


SV *splitstr (str, pos)
SV *str
int pos
CODE:
/* Splits 'str' into 2 pieces at pos; returns the first part
and leaves the second in str. */
	size_t len;
	char *b = SvPV(str, len);
	char a[pos+1];
	memcpy(a, b, pos);
	a[pos] = '\0';
	b += pos;
	sv_setpvn(str, b, len-pos);
	RETVAL = newSVpv(a, pos);
OUTPUT:
	RETVAL


void terminateDirPath (path)
SV *path
CODE:
// Appends '/' if not present.
	size_t len;
	char *str = SvPV(path, len);
	if (str[len - 1] != '/') {
		char replace[len + 2];
		strcpy(replace, str);
		replace[len] = '/';
		replace[len + 1] = '\0';
		sv_setpvn(path, replace, len + 1);
	}


void tailstr (s, pos)
SV *s
int pos
CODE:
// Splits 's' at 'pos' and discards the first part;
// nb. this does not safety check.
	STRLEN len;
	char *p = SvPV(s, len);
	p += pos;
	sv_setpvn(s, p, len-pos);


int toInteger (str)
SV *str
CODE:
// Sets the field value type to IV for subsequent use in C.
	char *data = SvPV_nolen(str);
	int len = strlen(data), i;

	for (i = 0; i < len; i++)
		if (data[i] < '0' || data[i] > '9') XSRETURN_IV(0);
	sv_setiv(str, strtol(data, NULL, 0));
	RETVAL = 1;
OUTPUT:
	RETVAL
