package Sloop::Logger::SimpleColor;
use strict;
use warnings;

use parent 'Sloop::Logger';

use Term::ANSIColor;

our $Reset = color('reset');

=encoding utf8

=head1 NAME

Sloop::Logger::SimpleColor

=head1 DESCRIPTION

A version of Sloop::Logger which uses ANSI escapes to color the output.
This is probably not desirable if you are logging to a file since text
viewers generally don't render it and the escapes will be seen as clutter.
Output to a normal linux terminal though, it's fine.

The color isn't applied to the timestamp.

=head1 REQUIRES

This refers only to things not part of Sloop or the perl core.

B<Term::ANSIColor>

=head1 SYNOPSIS

 my $logger = Sloop::Logger::SimpleColor->new (
     $color,
     logs => (optional) see Sloop::Logger
 );

B<$color> is passed straight through to Term::ANSIColor, so, e.g. 'yellow'
or 'rgb550' are both valid.

=cut
sub new {
	my ($class, $color) = (shift, shift);
	my $self = $class->SUPER::new(@_);
	$self->{color} = color($color);
	bless $self, $class;
}

sub out {
	$_[0]->SUPER::out (
		$_[1],
		$_[0]->{color}.$_[2].$Reset
	)
}

1;
