package Sloop::Logger::TriColor;
use strict;
use warnings;

use parent 'Sloop::Logger';

use Carp;
use Term::ANSIColor;

our $Reset = color('reset');

=encoding utf8

=head1 NAME

Sloop::Logger::TriColor

=head1 DESCRIPTION

A version of Sloop::Logger which uses ANSI escapes to color the output.
This is probably not desirable if you are logging to a file since text
viewers generally don't render it and the escapes will be seen as clutter.
Output to a normal linux terminal though, it's fine.

Three colors are used, one for each element of the 'logs' array (see
Sloop::Logger).

The colors aren't applied to the timestamp.

=head1 REQUIRES

This refers only to things not part of Sloop or the perl core.

B<Term::ANSIColor>

=head1 SYNOPSIS

 my $logger = Sloop::Logger::TriColor->new (
     $colors,
     logs => (optional), see Sloop::Logger
 );

B<$colors> is a array reference with three elements.  These are passed
through to Term::ANSIColor.  For example:

 [ 'red', 'green, 'blue' ]

These parallel the 'logs' array.

=cut
sub new {
	my ($class, $colors) = (shift, shift);
	croak __PACKAGE__."::new() No appropiate 'colors' hash provided.\n" if (
		ref($colors) ne 'ARRAY'
		|| $#{$colors} != 2
	);
	my $self = $class->SUPER::new(@_);
	my @colors = map { $_ ? color($_): "" } @{$colors};
	$self->{colors} = \@colors;
	bless $self, $class;
}


sub out {
	$_[0]->SUPER::out (
		$_[1],
		$_[0]->{colors}->[$_[1]].$_[2].$Reset
	);
}

1;
