#define PERL_NO_GET_CONTEXT
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"
#include "ppport.h"

#include <arpa/inet.h>
#include <errno.h>
#include <netinet/in.h>
#include <stdlib.h>
#include <string.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <sys/un.h>


struct sockaddr *createAddress (int proto, int port, char *addr, socklen_t *len) {
	if (proto == AF_LOCAL) {
		struct sockaddr_un *un = malloc(sizeof(struct sockaddr_un));
		un->sun_family = AF_LOCAL;
		strncpy(un->sun_path, addr, 107);
		un->sun_path[107] = '\0';
		*len = sizeof(struct sockaddr_un);
		return (struct sockaddr*)un;
	}
	port = htons(port);
	errno = 0; // Checked in caller.
	if (proto == AF_INET6) {
		struct sockaddr_in6 *in6 = malloc(sizeof(struct sockaddr_in));
		in6->sin6_family = AF_INET6;
		in6->sin6_port = port;
		int check = inet_pton(AF_INET6, addr, &(in6->sin6_addr));
		if (check <= 0) {
			free(in6);
			return NULL;
		}
		*len = sizeof(struct sockaddr_in6);
		return (struct sockaddr*)in6;
	}
	struct sockaddr_in *in = malloc(sizeof(struct sockaddr_in));
	in->sin_family = AF_INET;
	in->sin_port = port;
	int check = inet_pton(AF_INET, addr, &(in->sin_addr));
	if (check <= 0) {
		free(in);
		return NULL;
	}
	*len = sizeof(struct sockaddr_in);
	return (struct sockaddr*)in;
}


MODULE = Sloop::Other		PACKAGE = Sloop::Other

PROTOTYPES: ENABLE


int connectFD (self)
HV *self
CODE:
	// Get protocol.
	SV **field = hv_fetch(self, "proto", 5, 0);
	int proto = SvIV(*field);
	if (proto == 1) proto = AF_LOCAL;
	else if (proto == 6) proto = AF_INET6;
	else proto = AF_INET;
	// Get port.
	field = hv_fetch(self, "dest_port", 9, 0);
	int port = SvIV(*field);
	// Get address string.
	field = hv_fetch(self, "dest_addr", 9, 0);
	char *astr = SvPV_nolen(*field);

	// Create socket.
	int fd = socket(proto, SOCK_STREAM, 0);
	if (fd < 0) {
		// See comment in Server.xs Epoll() regarding strerror vs. strerror_r.
		char *msg = strerror(errno);
		hv_store(self, "error", 5, newSVpv(msg, strlen(msg)), 0);
		XSRETURN_IV(-1);
	}

	// Create address struct.
	socklen_t alen;
	struct sockaddr *addr = createAddress(proto, port, astr, &alen);
	if (!addr) {
		const char *msg = "Invalid dest_addr.";
		const char *p = msg;
		if (errno) p = strerror(errno);
		hv_store(self, "error", 5, newSVpv(p, strlen(p)), 0);
		XSRETURN_IV(-1);
	}

	// Connect to server.
	if (connect(fd, addr, alen) == -1) {
		free(addr);
		char *msg = strerror(errno);
		hv_store(self, "error", 5, newSVpv(msg, strlen(msg)), 0);
		XSRETURN_IV(-1);
	}
	free(addr);

	RETVAL = fd;
OUTPUT:
	RETVAL

