use strict;
use warnings FATAL => qw(all);

use Sloop::Constants (':Debug');
use Sloop::Client::Request;
use Sloop::Other::Regular;
use Sloop::Server;

use Test::More tests => 5;
BEGIN { use_ok('Sloop::Other') };

# Create a random payload to transfer.
my ($payload, $len) = randomInput(2345678);

# Create a sloop server to use as "the other" before
# we fork, so the port number is available.  Generally
# this is not a good practice, but it works here due
# to the limited number of connections (1).
my $sloop = Sloop::Server->new (
	port => 0,
	id => 'other'
);
die if !$sloop;
my $PortNo = $sloop->{port};

$sloop->{handlers} = {
	one => sub {
		my $client = shift;
		$client->reply(\$payload);
	},
	two => sub {
		my $client = shift;
		$client->reply(\"again");
	},
	three => sub {
		my $client = shift;
		$client->reply(\"the end");
		$client->setAfterReplyHandler (
			sub { exit 0 }
		);
	}
};

my $pid = fork;

if (!defined $pid) {
	print STDERR "Fork() failed: $!\n";
	exit 1;
}

if (!$pid) {
# Child process will be the party to contact.
# Throw away forked server output, otherwise it is not
# suppressed when run via 'make test'.
	my $garbage = "";
	close STDOUT;
	open STDOUT, '>', \$garbage;
	close STDERR;
	open STDERR, '>', \$garbage;
	$sloop->run;
} else {
	$sloop = Sloop::Server->new (
		port => 0,
		id => "ME!"
	);
	if (!$sloop) {
		`kill $pid`;
		exit 1;
	}

	my $copy = "";
	my $other = Sloop::Other::Regular->new (
		id => 'me',
		dest_addr => '127.0.0.1',
		dest_port => $PortNo,
		incoming => sub {
			my ($self, $msg, $len) = (shift, shift, shift);
			if (!$copy) {
			# Deal with HTTP header in first chunk.
				# Skip first line (HTTP 1.1 OK).
				$$msg = substr($$msg, index($$msg, "\r\n") + 2);
				my $headers = Sloop::Client::Request::getHeaders($msg);
				ok($headers->{server} eq 'Perl Sloop', 'Header check')
			}
			$copy .= $$msg;
			return 1 if length $copy < length $payload;
			ok ($copy eq $payload, 'Request response 1');
			$self->{incoming} = [
				sub {
					my ($self, $msg, $len) = (shift, shift, shift);
					$$msg = substr($$msg, index($$msg, "\r\n") + 2);
					my $headers = Sloop::Client::Request::getHeaders($msg);
					ok($$msg eq 'again', 'Request response 2');
					$self->message(\"GET /three HTTP/1.1\r\n\r\n");
					return 1;
				},
				sub {
					my ($self, $msg, $len) = (shift, shift, shift);
					$$msg = substr($$msg, index($$msg, "\r\n") + 2);
					my $headers = Sloop::Client::Request::getHeaders($msg);
					ok($$msg eq 'the end', 'Request response 3');
					exit 0;
				}
			];
			$self->message(\"GET /two HTTP/1.1\r\n\r\n");
		},
		logger => $sloop->{logger}
	);

	$sloop->connectOther($other);
	$other->message(\"GET /one HTTP/1.1\r\n\r\n");
	$sloop->{handlers} = {};
	$sloop->run;
}

sub randomInput {
	my $len = shift;
	open my $fh, '<', '/dev/urandom' or die "Could not open /dev/urandom: $!\n";
	my $data;
	my $bytes = read $fh, $data, $len;
	return ($data, $len);
}
