use strict;
use warnings;

use Test::More tests => 2;
BEGIN { use_ok('Sloop::Client::Secure') }

use LWP::UserAgent;
use LWP::Protocol::https;
use Sloop::Lib ('fastSlurp');
use Sloop::Logger;
use Sloop::Server;

die "Must be run in a directory containing 'localhost.cert'.\n"
	if (!-e -r 'localhost.cert');
die "Must be run in a directory containing 'server.privkey'.\n"
	if (!-e -r 'server.privkey');

my $payload = randomInput(2345678);

my $pid = fork;
die "fork() fail: $!" if !defined $pid;

if (!$pid) {
	my $garbage = "";
	open my $discard, '>', \$garbage;
	my $sloop = Sloop::Server->new (
		secure => {
			certificateChain => fastSlurp('localhost.cert'),
			privKey => fastSlurp('server.privkey')
		},
		logger => Sloop::Logger->new (
			logs => [ \*STDERR, \*STDERR, $discard ]
		),
		pollwait => 2,
		timeout => 2,
		port => 8181
	);
	die if !$sloop;
	$sloop->{handlers} = {
		'/' => sub {
			my $client = shift;
			$client->reply(\$payload, type=>'application/octet-stream');
			$sloop->stopListening;
		},
		done => sub {
			my $client = shift;
			$client->reply(\'ok');
		}
	};
	$sloop->run;
} else {
	my $client = LWP::UserAgent->new();
	die if !$client;
	$client->ssl_opts(verify_hostname => 0);

	my $reply = $client->get('https://127.0.0.1:8181');
	ok($reply->content eq $payload);
}


sub randomInput {
	my $len = shift;
	open my $fh, '<', '/dev/urandom' or die "Could not open /dev/urandom: $!\n";
	my $data;
	my $bytes = read $fh, $data, $len;
	return ($data, $len);
}
