use strict;
use warnings FATAL => qw(all);

#use Devel::Peek;
use Sloop::Logger;

use Test::More tests => 6;
BEGIN { use_ok('Sloop::WebSocket') };

{ package TestClient;

sub new {
	my $class = shift;
	my $self = {};
	bless $self, $class;
}

sub readData {
	return \$_[0]->{fake}
}

sub err_log {
	$_[0]->{logger}->out(0, $_[1]);
}

sub cancel { }
sub reply { }
sub setAfterReplyHandler { }
sub setEvents { }
sub setSituation { }

1;}


# Create fake client and minimal request.
my $client = TestClient->new();
$client->{logger} = Sloop::Logger->new();

$client->{request} = {
	headers => {
		'sec-websocket-key' => 'dGhlIHNhbXBsZSBub25jZQ==',
		'upgrade' => 'websocket'
	}
};

# Create a WS object assigning callback params to an array ref.
my $check;
my $wsock = Sloop::WebSocket->new (
	$client,
	dataIn => sub {
		shift;
		$check = \@_;
	},
	onControl => sub {
		shift;
		$check = \@_;
	}
);


# Simple message test.
$client->{fake} = pack (
	'C[2]L',
	128 + Sloop::WebSocket::WS_PONG,
	128 + 11,
	0
);
$client->{fake} .= "hello world";

$wsock->incoming;

#print "Payload ref count: ".Devel::Peek::SvREFCNT($check->[0])."\n";
#print "Meta ref count: ".Devel::Peek::SvREFCNT($check->[1])."\n";

is_deeply(
	$check,
	[
		\"hello world",
		{
			length => 11,
			opcode => Sloop::WebSocket::WS_PONG,
			FIN => 1,
			RSV1 => 0,
			RSV2 => 0,
			RSV3 => 0
		}
    ],
	'Simple message.'
);


# Large binary message.
my ($payload, $plsz) = randomInput(654321);

my $msg = pack (
	'C[2]L>[2]L',
	128 + Sloop::WebSocket::WS_BINARY,
	255, 0,
	$plsz,
	0	# Masking is integration tested, no need to do it here.
).$payload;

# Feed the message in chunks to test incomplete frame handling.
#$client->{fake} = $msg;
$client->{fake} = substr($msg, 0, 4);
$wsock->incoming;
$client->{fake} = substr($msg, 4, 10000);
$wsock->incoming;
$client->{fake} = substr($msg, 10004);
$wsock->incoming;

#print "Payload ref count: ".Devel::Peek::SvREFCNT($check->[0])."\n";
#print "Meta ref count: ".Devel::Peek::SvREFCNT($check->[1])."\n";

is_deeply (
	$check,
	[
		\$payload,
		{
			length => $plsz,
			opcode => Sloop::WebSocket::WS_BINARY,
			FIN => 1,
			RSV1 => 0,
			RSV2 => 0,
			RSV3 => 0
		}
	], "Large binary message."
);


# Large (64-bit size) make frame test using same payload.
my $frame = Sloop::WebSocket::makeFrame (
	\$payload,
	{
		opcode => Sloop::WebSocket::WS_BINARY,
	}
);

my $verify = pack (
	'C[2]L>[2]',
	128 + Sloop::WebSocket::WS_BINARY,
	127, 0,
	$plsz
).$payload;

ok($verify eq $frame, "Make frame -- large.");

#print "Frame ref count: ".Devel::Peek::SvREFCNT($frame)."\n";


# Medium (16-bit size) make frame test.
my ($randata, $len) = randomInput(1024);

$verify = pack (
	'C[2]S>',
	128 + Sloop::WebSocket::WS_CLOSE,
	126,
	$len
).$randata;

$frame = Sloop::WebSocket::makeFrame (
	\$randata,
	{
		opcode => Sloop::WebSocket::WS_CLOSE,
	}
);

ok($verify eq $frame, "Make frame -- medium.");


# Small make frame test.
$msg = "This is a short frame.";
ok (
	Sloop::WebSocket::makeFrame(\$msg, {}) eq pack (
		'C[2]',
		128 + Sloop::WebSocket::WS_TEXT,
		length $msg
	).$msg,
	"Make frame -- small."
);


sub randomInput {
	my $len = shift;
	open my $fh, '<', '/dev/urandom' or die "Could not open /dev/urandom: $!\n";
	my $data;
	my $bytes = read $fh, $data, $len;
	return ($data, $len);
}


sub showBytes {
	my ($count, $max) = (0, pop);
	foreach (split(//, $_[0])) {
		print ord($_)." ";
		last if ++$count == $max;
	}
	print "\n";
}
